/// Type alias for json object map
typedef JsonObject = Map<String, dynamic>;

/// Mixin for Data Transfer Objects
/// Every subclass of this mixin must also provide fromJson static method:
/// ```dart
/// static Foo fromJson(JsonObject json) => Foo(name: json['name'], age: json['age']);
/// ```
mixin DTO {
  /// Converts this instance into a json object map. E.g. JsonObject toJson() => {'name': name, 'age': age};
  JsonObject toJson();

  /// Default toString implementation: E.g. Foo(name: Ugo, age: 37)
  @override
  String toString() => '$runtimeType(${toJson().entries.map((entry) => '${entry.key}: ${entry.value}').join(', ')})';
}
